.. :changelog:

History
-------

0.2.0 (2017-08-16)
++++++++++++++++++

* Speed up import function (`#9`_).
* Implement basic admin pages (`#7`_).

.. _#9: https://github.com/pbaranay/django-magic-cards/issues/9
.. _#7: https://github.com/pbaranay/django-magic-cards/issues/7

0.1.1 (2017-08-10)
++++++++++++++++++

* Increase maximum length of a `Card`'s `name` (`#2`_).

.. _#2: https://github.com/pbaranay/django-magic-cards/issues/2

0.1.0 (2017-08-08)
++++++++++++++++++

* First release on PyPI.
